import { TokenAmount } from './fractions/tokenAmount';
import JSBI from 'jsbi';
import { BigintIsh, ChainId } from '../constants';
import { Token } from './token';
import { Pair } from "../entities";
export declare class Pylon {
    readonly floatLiquidityToken: Token;
    readonly anchorLiquidityToken: Token;
    readonly pair: Pair;
    private readonly tokenAmounts;
    static getAddress(tokenA: Token, tokenB: Token): string;
    static getLiquidityAddresses(tokenA: Token, tokenB: Token): [string, string];
    constructor(pair: Pair, tokenAmount0: TokenAmount, tokenAmount1: TokenAmount);
    /**
     * Returns true if the token is either token0 or token1
     * @param token to check
     */
    involvesToken(token: Token): boolean;
    /**
     * Returns the chain ID of the tokens in the pair.
     */
    get chainId(): ChainId;
    get token0(): Token;
    get token1(): Token;
    get reserve0(): TokenAmount;
    get reserve1(): TokenAmount;
    private sqrt;
    private translateToPylon;
    private updateSync;
    private calculatePTU;
    private getLiquidityFromPoolTokensLiquidity;
    reserveOf(token: Token): TokenAmount;
    getOutputAmount(inputAmount: TokenAmount): [TokenAmount, Pair];
    getInputAmount(outputAmount: TokenAmount): [TokenAmount, Pair];
    initializeValues(totalSupply: TokenAmount, tokenAmountA: TokenAmount, tokenAmountB: TokenAmount): [JSBI, JSBI];
    getAnchorAsync100LiquidityMinted(totalSupply: TokenAmount, anchorTotalSupply: TokenAmount, tokenAmount: TokenAmount, anchorVirtualBalance: BigintIsh, floatVirtualBalance: BigintIsh, gamma: BigintIsh, kLast: BigintIsh, ptb: TokenAmount, lastPoolToken: TokenAmount): TokenAmount;
    getFloatAsync100LiquidityMinted(totalSupply: TokenAmount, floatTotalSupply: TokenAmount, tokenAmount: TokenAmount, anchorVirtualBalance: BigintIsh, floatVirtualBalance: BigintIsh, gamma: BigintIsh, kLast: BigintIsh, ptb: TokenAmount, lastPoolToken: TokenAmount): TokenAmount;
    getAnchorAsyncLiquidityMinted(totalSupply: TokenAmount, anchorTotalSupply: TokenAmount, tokenAmountA: TokenAmount, tokenAmountB: TokenAmount, anchorVirtualBalance: BigintIsh, floatVirtualBalance: BigintIsh, gamma: BigintIsh, kLast: BigintIsh, ptb: TokenAmount, lastPoolToken: TokenAmount): TokenAmount;
    getFloatAsyncLiquidityMinted(totalSupply: TokenAmount, floatTotalSupply: TokenAmount, tokenAmountA: TokenAmount, tokenAmountB: TokenAmount, anchorVirtualBalance: BigintIsh | JSBI, floatVirtualBalance: BigintIsh, gammaLast: BigintIsh, kLast: BigintIsh, ptb: TokenAmount, lastPoolToken: TokenAmount): TokenAmount;
    getAnchorSyncLiquidityMinted(totalSupply: TokenAmount, anchorTotalSupply: TokenAmount, tokenAmount: TokenAmount, anchorVirtualBalance: BigintIsh, floatVirtualBalance: BigintIsh, gammaLast: BigintIsh, kLast: BigintIsh, ptb: TokenAmount, lastPoolToken: TokenAmount): TokenAmount;
    getFloatSyncLiquidityMinted(totalSupply: TokenAmount, floatTotalSupply: TokenAmount, tokenAmount: TokenAmount, anchorVirtualBalance: BigintIsh, floatVirtualBalance: BigintIsh, gammaLast: BigintIsh, kLast: BigintIsh, ptb: TokenAmount, lastPoolToken: TokenAmount): TokenAmount;
    calculatePTUToAmount(totalSupply: TokenAmount, floatTotalSupply: TokenAmount, tokenAmount: TokenAmount, anchorVirtualBalance: JSBI, ptb: JSBI, gamma: JSBI, isAnchor: boolean): JSBI;
    calculateLPTU(totalSupply: TokenAmount, ptTotalSupply: TokenAmount, tokenAmount: JSBI, anchorVirtualBalance: JSBI, gamma: JSBI, ptb: TokenAmount, isAnchor: boolean): JSBI;
    burnFloat(totalSupply: TokenAmount, floatTotalSupply: TokenAmount, tokenAmountOut: TokenAmount, anchorVirtualBalance: JSBI, floatVirtualBalance: JSBI, gammaLast: JSBI, kLast: JSBI, ptb: TokenAmount, lastPoolToken: TokenAmount): JSBI;
    burnAnchor(totalSupply: TokenAmount, anchorTotalSupply: TokenAmount, tokenAmountOut: TokenAmount, anchorVirtualBalance: JSBI, floatVirtualBalance: JSBI, gammaLast: JSBI, kLast: JSBI, ptb: TokenAmount, lastPoolToken: TokenAmount): JSBI;
    burnAsyncAnchor(totalSupply: TokenAmount, anchorTotalSupply: TokenAmount, tokenAmountOut: TokenAmount, anchorVirtualBalance: JSBI, floatVirtualBalance: JSBI, gammaLast: JSBI, kLast: JSBI, ptb: TokenAmount, lastPoolToken: TokenAmount): [JSBI, JSBI];
    burnAsyncFloat(totalSupply: TokenAmount, floatTotalSupply: TokenAmount, tokenAmountOut: TokenAmount, anchorVirtualBalance: JSBI, floatVirtualBalance: JSBI, gammaLast: JSBI, kLast: JSBI, ptb: TokenAmount, lastPoolToken: TokenAmount): [JSBI, JSBI];
    getLiquidityValue(token: Token, totalSupply: TokenAmount, liquidity: TokenAmount, feeOn?: boolean, kLast?: BigintIsh): TokenAmount;
}
